@@ -30,11 +30,11 @@ class CustomCaptchaTask:
 							 "softId": app_key
                              }
         # заполняем поле с заданием пользователю        
-        if assignment:
-            self.task_payload['task'].update({'assignment': assignment})
+		if assignment:
+			self.task_payload['task'].update({'assignment': assignment})
         # заполняем поле с произвольной формой в формате JSON
-        if forms:
-            self.task_payload['task'].update({'forms': forms})
+		if forms:
+			self.task_payload['task'].update({'forms': forms})
 		
         # задаём callbackUrl если передан
 		if callbackUrl:
@@ -42,7 +42,14 @@ class CustomCaptchaTask:
 
 		# пайлоад для получения ответа сервиса
 		self.result_payload = {"clientKey": anticaptcha_key}
-		
+    
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        if exc_type:
+            return False
+        return True
 		
 	# Работа с капчёй
 	def captcha_handler(self, imageUrl: str):
@@ -97,11 +104,11 @@ class aioCustomCaptchaTask:
 							 "softId": app_key
                              }
         # заполняем поле с заданием пользователю        
-        if assignment:
-            self.task_payload['task'].update({'assignment': assignment})
+		if assignment:
+			self.task_payload['task'].update({'assignment': assignment})
         # заполняем поле с произвольной формой в формате JSON
-        if forms:
-            self.task_payload['task'].update({'forms': forms})
+		if forms:
+			self.task_payload['task'].update({'forms': forms})
 		
         # задаём callbackUrl если передан
 		if callbackUrl:
@@ -109,6 +116,14 @@ class aioCustomCaptchaTask:
 
 		# пайлоад для получения ответа сервиса
 		self.result_payload = {"clientKey": anticaptcha_key}
+    
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_value, traceback):
+        if exc_type:
+            return False
+        return True
 
 	# Работа с капчёй
 	async def captcha_handler(self, imageUrl: str):
